@@ -7,3 +7,6 @@ from .Text import *
 # from .Exceptions import *
 from .Conversions import *
 from .Classes import *
+from .Testing import *
+from .Time import *
+from .Internet import *
